<?php

class PageNavi_Options_Page extends scbAdminPage {

	function setup() {

		$this->args = array(
			'page_title' => __( 'PageNavi Settings', 'eightsquare' ),
			'menu_title' => __( 'PageNavi', 'eightsquare' ),
			'page_slug' => 'pagenavi',
		);
	}

	function validate( $options ) {
		foreach ( array( 'style', 'num_pages', 'num_larger_page_numbers', 'larger_page_numbers_multiple' ) as $key )
			$options[$key] = absint( @$options[$key] );

		foreach ( array( 'use_pagenavi_css', 'always_show' ) as $key )
			$options[$key] = (bool) @$options[$key];

		return $options;
	}

	function page_content() {
		$rows = array(
			array(
				'title' => __( 'Text For Number Of Pages', 'eightsquare' ),
				'type' => 'text',
				'name' => 'pages_text',
				'extra' => 'size="50"',
				'desc' => '<br />
					%CURRENT_PAGE% - ' . __( 'The current page number.', 'eightsquare' ) . '<br />
					%TOTAL_PAGES% - ' . __( 'The total number of pages.', 'eightsquare' )
			),

			array(
				'title' => __( 'Text For Current Page', 'eightsquare' ),
				'type' => 'text',
				'name' => 'current_text',
				'desc' => '<br />
					%PAGE_NUMBER% - ' . __( 'The page number.', 'eightsquare' )
			),

			array(
				'title' => __( 'Text For Page', 'eightsquare' ),
				'type' => 'text',
				'name' => 'page_text',
				'desc' => '<br />
					%PAGE_NUMBER% - ' . __( 'The page number.', 'eightsquare' )
			),

			array(
				'title' => __( 'Text For First Page', 'eightsquare' ),
				'type' => 'text',
				'name' => 'first_text',
				'desc' => '<br />
					%TOTAL_PAGES% - ' . __( 'The total number of pages.', 'eightsquare' )
			),

			array(
				'title' => __( 'Text For Last Page', 'eightsquare' ),
				'type' => 'text',
				'name' => 'last_text',
				'desc' => '<br />
					%TOTAL_PAGES% - ' . __( 'The total number of pages.', 'eightsquare' )
			),

			array(
				'title' => __( 'Text For Previous Page', 'eightsquare' ),
				'type' => 'text',
				'name' => 'prev_text',
			),

			array(
				'title' => __( 'Text For Next Page', 'eightsquare' ),
				'type' => 'text',
				'name' => 'next_text',
			),

			array(
				'title' => __( 'Text For Previous ...', 'eightsquare' ),
				'type' => 'text',
				'name' => 'dotleft_text',
			),

			array(
				'title' => __( 'Text For Next ...', 'eightsquare' ),
				'type' => 'text',
				'name' => 'dotright_text',
			),
		);

		$out =
		 html( 'h3', __( 'Page Navigation Text', 'eightsquare' ) )
		.html( 'p', __( 'Leaving a field blank will hide that part of the navigation.', 'eightsquare' ) )
		.$this->table( $rows );


		$rows = array(
			array(
				'title' => __( 'Use pagenavi-css.css', 'eightsquare' ),
				'type' => 'checkbox',
				'name' => 'use_pagenavi_css',
			),

			array(
				'title' => __( 'Page Navigation Style', 'eightsquare' ),
				'type' => 'select',
				'name' => 'style',
				'values' => array( 1 => __( 'Normal', 'eightsquare' ), 2 => __( 'Drop-down List', 'eightsquare' ) ),
				'text' => false
			),

			array(
				'title' => __( 'Always Show Page Navigation', 'eightsquare' ),
				'type' => 'checkbox',
				'name' => 'always_show',
				'desc' => __( "Show navigation even if there's only one page.", 'eightsquare' )
			),

			array(
				'title' => __( 'Number Of Pages To Show', 'eightsquare' ),
				'type' => 'text',
				'name' => 'num_pages',
				'extra' => 'class="small-text"'
			),

			array(
				'title' => __( 'Number Of Larger Page Numbers To Show', 'eightsquare' ),
				'type' => 'text',
				'name' => 'num_larger_page_numbers',
				'extra' => 'class="small-text"',
				'desc' =>
				'<br />' . __( 'Larger page numbers are in addition to the normal page numbers. They are useful when there are many pages of posts.', 'eightsquare' ) .
				'<br />' . __( 'For example, WP-PageNavi will display: Pages 1, 2, 3, 4, 5, 10, 20, 30, 40, 50.', 'eightsquare' ) .
				'<br />' . __( 'Enter 0 to disable.', 'eightsquare' )
			),

			array(
				'title' => __( 'Show Larger Page Numbers In Multiples Of', 'eightsquare' ),
				'type' => 'text',
				'name' => 'larger_page_numbers_multiple',
				'extra' => 'class="small-text"',
				'desc' =>
				'<br />' . __( 'For example, if mutiple is 5, it will show: 5, 10, 15, 20, 25', 'eightsquare' )
			),
		);

		$out .=
		 html( 'h3', __( 'Page Navigation Options', 'eightsquare' ) )
		.$this->table( $rows );

		echo $this->form_wrap( $out );
	}
}

